==> carbon-component-mapper-3.11.4.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';

var PlainText = function PlainText(_ref) {
  var label = _ref.label,
      element = _ref.element,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, ["label", "element", "component"]);

  return label.split('\n').map(function (paragraph, index) {
    return React.createElement(element, _objectSpread({
      key: index
    }, rest), paragraph);
  });
};

PlainText.propTypes = {
  label: PropTypes.string,
  element: PropTypes.string,
  component: PropTypes.string
};
PlainText.defaultProps = {
  element: 'p'
};
export default PlainText;

==> carbon-component-mapper-3.13.0.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "element", "component"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';

var PlainText = function PlainText(_ref) {
  var label = _ref.label,
      element = _ref.element,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  return label.split('\n').map(function (paragraph, index) {
    return /*#__PURE__*/React.createElement(element, _objectSpread({
      key: index
    }, rest), paragraph);
  });
};

PlainText.propTypes = {
  label: PropTypes.string,
  element: PropTypes.string,
  component: PropTypes.string
};
PlainText.defaultProps = {
  element: 'p'
};
export default PlainText;
